<div align="center">
    <img src="../../docs/images/logo-title.png" height="80px">
    <h3>The Graph Of LIfe Library.</h3>
</div>


## What is in this folder? 

- ✅ `datamodule.py`: loading from disc and process into dataloader
- `collate.py` : defining the collate function to use for the dataloader
- `dataset.py`: defining the dataset class
- `normalization.py`: defining label normalization
- `sdf2csv.py`: convertion function from sdf to csv for the ogb pcqm dataset
- `smiles_transform.py`: transform smiles to molecule object 
- `utils.py`: utility functions for dataset loading 